@@ -321,6 +321,7 @@ def objects():
     #~ yield country('SUHH',"Soviet Union")
     
     eupen = City.objects.get(name__exact='Eupen')
+    stvith = City.objects.get(zip_code__exact='4780')
     kettenis = City.objects.get(name__exact='Kettenis')
     vigala = City.objects.get(name__exact='Vigala')
     ee = countries.Country.objects.get(pk='EE')
@@ -382,6 +383,24 @@ def objects():
     yield company(name=u"Bourseaux Alexandre",street=u'Aachener Straße',street_no=21,**kw)
     yield company(name=u"Baguette Stéphanie",street=u'Gospertstraße',street_no=24,**kw)
     
+    
+    cct = ClientContactType(**babel_values('name',
+          de="Gerichtsvollzieher",
+          fr="Huissier de justice",
+          en="Bailiff"
+          ))
+    yield cct
+    kw = dict(client_contact_type=cct,country=belgium,city=eupen)
+    #~ kw = dict(is_attorney=True,country=belgium,city=eupen)
+    yield company(name="Demarteau Bernadette",street='Aachener Straße',street_no=25,**kw)
+    kw.update(city=stvith)
+    yield company(name="Schmitz Marc",street='Rodter Straße',street_no=43, street_box="B",**kw)
+    
+    settings.SITE.site_config.debts_bailiff_type = cct
+    yield settings.SITE.site_config
+    
+    
+    
     def person2client(p,**kw):
         c = mti.insert_child(p,Client,**kw)
         c.client_state = pcsw.ClientStates.coached
