@@ -300,6 +300,44 @@ def setup_reports_menu(site,ui,profile,m):
     m.add_action(site.modules.pcsw.UsersWithClients)
     m.add_action(site.modules.pcsw.ClientsTest)
         
+
+
+@dd.receiver(dd.post_startup)
+def register_change_watchers(sender,**kw):
+    """
+    A Lino/Welfare site by default watches the changes to certain Client fields
+    and to all Contract fields.
+    """
+    
+    self = sender
+    
+    #~ super(Site,self).on_site_startup()
+    
+    from lino.modlib.changes.models import watch_changes as wc
+    
+    #~ self.modules.pcsw.Client.watch_changes('first_name last_name national_id client_state')
+    wc(self.modules.contacts.Partner)
+    wc(self.modules.contacts.Person,master_key='partner_ptr')
+    wc(self.modules.contacts.Company,master_key='partner_ptr')
+    wc(self.modules.pcsw.Client,master_key='partner_ptr')
+    wc(self.modules.pcsw.Coaching,master_key='client__partner_ptr')
+    wc(self.modules.pcsw.ClientContact,master_key='client__partner_ptr')
+    wc(self.modules.jobs.Candidature,master_key='person__partner_ptr')
+    
+    #~ self.modules.notes.Note.watch_changes(master_key='project')
+    #~ self.modules.outbox.Mail.watch_changes(master_key='project')
+    #~ self.modules.cal.Event.watch_changes(master_key='project')
+    #~ self.modules.debts.Budget.watch_changes(master_key='partner')
+    
+    # ContractBase is abstract, so it's not under self.modules
+    from lino_welfare.modlib.isip.models import ContractBase
+    #~ ContractBase.watch_changes(master_key='client__partner_ptr')
+    wc(ContractBase, master_key='client__partner_ptr')
+    
+    from lino_welfare.modlib.cbss.models import CBSSRequest
+    wc(CBSSRequest,master_key='person__partner_ptr')
+                
+            
   
 
 def site_setup(site):
@@ -309,7 +347,7 @@ def site_setup(site):
     This includes especially those detail layouts 
     which depend on the *combination* of installed modules.
     """
-    
+   
     #~ class HouseholdDetail(households.HouseholdDetail):
         #~ box3 = """
         #~ country region
@@ -342,14 +380,14 @@ def site_setup(site):
     
     site.modules.ui.SiteConfigs.set_detail_layout("""
     site_company system_note_type default_build_method 
-    next_partner_id:20 job_office
+    next_partner_id:20 job_office debts_bailiff_type master_budget
     signer1 signer2
+    signer1_function signer2_function 
     constants
     # lino.ModelsBySite
     """,constants="""
     propgroup_skills propgroup_softskills propgroup_obstacles
     residence_permit_upload_type work_permit_upload_type driving_licence_upload_type
-    signer1_function signer2_function 
     """)
     
     site.modules.properties.Properties.set_detail_layout("""
